summaryrefslogtreecommitdiff
path: root/pear
diff options
context:
space:
mode:
Diffstat (limited to 'pear')
-rw-r--r--pear/Cache.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/pear/Cache.php b/pear/Cache.php
index efa05c9156..04a662709a 100644
--- a/pear/Cache.php
+++ b/pear/Cache.php
@@ -257,12 +257,12 @@ class Cache extends PEAR {
* @return boolean
* @access public
*/
- function delete($id, $group = 'default') {
+ function remove($id, $group = 'default') {
if (!$this->caching)
return true;
- return $this->container->delete($id, $group);
- } // end func delete
+ return $this->container->remove($id, $group);
+ } // end func remove
/**
* Flushes the cache - removes all data from it